@@ -4,8 +4,9 @@ Purpose
 =======
 
 ncvue is a minimal GUI for a quick view of netcdf files.
-It is aiming to be a drop-in replacement for ncview,
-being slightly more general than ncview, which targets maps.
+It is aiming to be a drop-in replacement for ncview and panoply,
+being slightly more general than ncview targeting maps but providing
+animations, zooming and panning capabilities unlike panoply.
 
 :copyright: Copyright 2020 Matthias Cuntz, see AUTHORS.rst for details.
 :license: MIT License, see LICENSE for details.
@@ -17,7 +18,9 @@ from .version import __version__, __author__
 # helper functions
 # general helper function
 from .ncvutils   import DIMMETHODS, SEPCHAR
-from .ncvutils   import add_cyclic_point, clone_ncvmain, get_slice
+from .ncvutils   import add_cyclic_point, clone_ncvmain
+from .ncvutils   import format_coord_contour, format_coord_map
+from .ncvutils   import format_coord_scatter, get_slice
 from .ncvutils   import list_intersection, set_axis_label, set_miss
 from .ncvutils   import spinbox_values, vardim2var, zip_dim_name_length
 
