@@ -17,6 +17,8 @@ History:
 
 * Written Dec 2020-Jan 2021 by Matthias Cuntz (mc (at) macu (dot) de)
 * Open new netcdf file, communicate via top widget, Jan 2021, Matthias Cuntz
+* Write coordinates and value on bottom of plotting canvas,
+  May 2021, Matthias Cuntz
 
 .. moduleauthor:: Matthias Cuntz
 
@@ -37,8 +39,8 @@ from tkinter import filedialog
 import os
 import numpy as np
 import netCDF4 as nc
-from .ncvutils   import add_cyclic_point, clone_ncvmain, set_axis_label
-from .ncvutils   import set_miss, vardim2var
+from .ncvutils   import add_cyclic_point, clone_ncvmain, format_coord_map
+from .ncvutils   import set_axis_label, set_miss, vardim2var
 from .ncvmethods import analyse_netcdf, get_slice_miss, get_miss
 from .ncvmethods import set_dim_lon, set_dim_lat, set_dim_var
 from .ncvwidgets import add_checkbutton, add_combobox, add_entry, add_imagemenu
@@ -46,7 +48,9 @@ from .ncvwidgets import add_menu, add_scale, add_spinbox, add_tooltip
 import matplotlib as mpl
 mpl.use('TkAgg')
 from matplotlib import pyplot as plt
-plt.style.use('seaborn-darkgrid')
+# plt.style.use('seaborn-darkgrid')
+plt.style.use('seaborn-dark')
+# plt.style.use('fast')
 import cartopy.crs as ccrs
 
 
@@ -431,7 +435,8 @@ class ncvMap(ttk.Frame):
             vx = vardim2var(x)
             xx = self.fi.variables[vx]
             xx = get_slice_miss(self, self.lond, xx)
-            xx = (xx + 360.) % 360.
+            if np.any(np.isfinite(xx)):
+                xx = (xx + 360.) % 360.
             if (xx.max() - xx.min()) > 150.:
                 self.iglobal.set(1)
             else:
@@ -979,7 +984,10 @@ class ncvMap(ttk.Frame):
                     self.iunlim = 0
             else:
                 self.iunlim = 0
-            self.nunlim = self.fi.variables[vz].shape[self.iunlim]
+            if self.fi.variables[vz].ndim > 0:
+                self.nunlim = self.fi.variables[vz].shape[self.iunlim]
+            else:
+                self.nunlim = 0
 
     #
     # Plotting
@@ -1089,7 +1097,10 @@ class ncvMap(ttk.Frame):
             xx = get_slice_miss(self, self.lond, xx)
             # set central longitude of projection
             # make in 0-360, otherwise always 0 if -180 to 180
-            xx360 = (xx + 360.) % 360.
+            if np.any(np.isfinite(xx)):
+                xx360 = (xx + 360.) % 360.
+            else:
+                xx360 = xx
             if xx.size > 1:
                 if xx.ndim > 1:
                     x0 = xx[:, 0].mean()
@@ -1138,12 +1149,12 @@ class ncvMap(ttk.Frame):
             # set x and y to index if not selected
             if (x == ''):
                 nx = vv.shape[1]
-                xx = -180. + np.arange(nx) * 360./float(nx)
+                xx = -180. + np.arange(nx) / float(nx) * 360.
                 xx += 0.5 * (xx[1] - xx[0])
                 xlab = ''
             if (y == ''):
                 ny = vv.shape[0]
-                yy = np.arange(ny) * 180./float(ny) - 90.
+                yy = -90. + np.arange(ny) / float(ny) * 180.
                 yy += 0.5 * (yy[1] - yy[0])
                 ylab = ''
             # plot
@@ -1190,6 +1201,17 @@ class ncvMap(ttk.Frame):
                 # cartopy.contourf needs cyclic longitude for wrap around
                 self.ivvc, self.ixxc, self.iyyc = add_cyclic_point(
                     self.ivv, coord=self.ixx, rowcoord=self.iyy)
+                # # special treatment if fringe points < 1e-4 apart
+                # # This works but it did still not display correctly the
+                # # test file of GDPS from cuizinart
+                # # -> do not do it for the moment
+                # if np.ma.allclose(np.ma.sin(np.deg2rad(self.ixxc[:, 0])),
+                #                   np.ma.sin(np.deg2rad(self.ixxc[:, -1])),
+                #                   atol=1.0e-5):
+                #     if np.ma.allclose(self.ixxc[:, 0], self.ixxc[:, -1],
+                #                       atol=1.0e-4):
+                #         self.ixxc = self.ixxc.astype(float)
+                #         self.ixxc[:, -1] = self.ixxc[:, 0] + 360.
             else:
                 self.ivvc = self.ivv
                 self.ixxc = self.ixx
@@ -1202,7 +1224,8 @@ class ncvMap(ttk.Frame):
             self.ncmap   = self.ncmap if self.ncmap < 256 else 15
             self.iextend = extend
             # self.img_extent = (xx.min(), xx.max(), yy.min(), yy.max())
-            # print(self.ixx.min(), self.ixx.max(), self.iyy.min(), self.iyy.max())
+            # print(self.ixx.min(), self.ixx.max(), self.iyy.min(),
+            #       self.iyy.max())
             if mesh:
                 try:
                     # vv is matrix notation: (row, col)
@@ -1246,6 +1269,8 @@ class ncvMap(ttk.Frame):
                           self.ivvc.shape)
                     return
             self.cb.set_label(vlab)
+            self.axes.format_coord = lambda x, y: format_coord_map(
+                x, y, self.axes, self.ixx, self.iyy, self.ivv)
         # help(self.figure)
         if self.iiglobal:
             self.axes.set_global()
