@@ -18,6 +18,8 @@ History:
 
 * Written Nov-Dec 2020 by Matthias Cuntz (mc (at) macu (dot) de)
 * Open new netcdf file, communicate via top widget, Jan 2021, Matthias Cuntz
+* Write left-hand side and right-hand side values on bottom of plotting canvas,
+  May 2021, Matthias Cuntz
 
 .. moduleauthor:: Matthias Cuntz
 
@@ -37,7 +39,8 @@ except Exception:
 from tkinter import filedialog
 import numpy as np
 import netCDF4 as nc
-from .ncvutils   import clone_ncvmain, set_axis_label, vardim2var
+from .ncvutils   import clone_ncvmain, format_coord_scatter
+from .ncvutils   import set_axis_label, vardim2var
 from .ncvmethods import analyse_netcdf, get_slice_miss
 from .ncvmethods import set_dim_x, set_dim_y, set_dim_y2
 from .ncvwidgets import add_checkbutton, add_combobox, add_entry
@@ -45,7 +48,9 @@ from .ncvwidgets import add_spinbox, add_tooltip
 import matplotlib
 matplotlib.use('TkAgg')
 from matplotlib import pyplot as plt
-plt.style.use('seaborn-darkgrid')
+# plt.style.use('seaborn-darkgrid')
+plt.style.use('seaborn-dark')
+# plt.style.use('fast')
 
 
 __all__ = ['ncvScatter']
@@ -125,6 +130,9 @@ class ncvScatter(ttk.Frame):
         # self.canvas.get_tk_widget().columnconfigure(0, weight=1)
         # self.canvas.get_tk_widget().rowconfigure(0, weight=1)
 
+        # self.canvas.mpl_connect('pick_event', self.onpick)
+        # self.canvas.mpl_connect('button_press_event', self.onpick)
+
         # matplotlib toolbar
         self.toolbar = NavigationToolbar2Tk(self.canvas, self)
         self.toolbar.update()
@@ -431,6 +439,16 @@ class ncvScatter(ttk.Frame):
             set_dim_y(self)
             self.redraw()
 
+    # def onpick(self, event):
+    #     print('in pick')
+    #     print('you pressed', event.button, event.xdata, event.ydata)
+    #     thisline = event.artist
+    #     xdata = thisline.get_xdata()
+    #     ydata = thisline.get_ydata()
+    #     ind = event.ind
+    #     points = tuple(zip(xdata[ind], ydata[ind]))
+    #     print('onpick points:', points)
+
     def prev_y(self):
         """
         Command called if previous button for the left-hand-side y-variable was
@@ -935,14 +953,15 @@ class ncvScatter(ttk.Frame):
                 xlab = ''
             # set y-axes to nan if not selected
             if (y == ''):
-                yy   = np.ones_like(xx)*np.nan
+                yy   = np.ones_like(xx, dtype='float') * np.nan
                 ylab = ''
             if (y2 == ''):
-                yy2   = np.ones_like(xx)*np.nan
+                yy2   = np.ones_like(xx, dtype='float') * np.nan
                 ylab2 = ''
             # plot
             # y-axis
             try:
+                # , picker=True, pickradius=5)
                 self.line_y = self.axes.plot(xx, yy)
             except Exception:
                 estr  = 'Scatter: x (' + vx + ') and y (' + vy + ')'
@@ -953,12 +972,15 @@ class ncvScatter(ttk.Frame):
             self.axes.yaxis.set_label_text(ylab)
             # y2-axis
             try:
+                # , picker=True, pickradius=5)
                 self.line_y2 = self.axes2.plot(xx, yy2)
             except Exception:
                 estr  = 'Scatter: x (' + vx + ') and y2 (' + vy2 + ')'
                 estr += ' shapes do not match for plot:'
                 print(estr, xx.shape, yy2.shape)
                 return
+            self.axes2.format_coord = lambda x, y: format_coord_scatter(
+                x, y, self.axes, self.axes2, xx.dtype, yy.dtype, yy2.dtype)
             self.axes2.xaxis.set_label_text(xlab)
             self.axes2.yaxis.set_label_text(ylab2)
             # styles, invert, same axes, etc.
