@@ -24,6 +24,10 @@ History:
 * added SEPCHAR and DIMMETHODS, Jan 2021, Matthias Cuntz
 * pass only ncvMain widget to clone_ncvmain, Jan 2021, Matthias Cuntz
 * pass only root widget to clone_ncvmain, Jan 2021, Matthias Cuntz
+* set correct missing value for date variable in numpy's datetime64[ms] format
+  May 2021, Matthias Cuntz
+* added format_coord functions for scatter, contour, and map,
+  May 2021, Matthias Cuntz
 
 .. moduleauthor:: Matthias Cuntz
 
@@ -34,6 +38,9 @@ The following functions are provided:
    SEPCHAR
    add_cyclic_point
    clone_ncvmain
+   format_coord_contour
+   format_coord_map
+   format_coord_scatter
    get_slice
    list_intersection
    set_axis_label
@@ -45,10 +52,15 @@ The following functions are provided:
 from __future__ import absolute_import, division, print_function
 import tkinter as tk
 import numpy as np
+import matplotlib.dates as mpld
+import cartopy.crs as ccrs
+import platform
 
 
 __all__ = ['DIMMETHODS', 'SEPCHAR',
-           'add_cyclic_point', 'clone_ncvmain', 'get_slice',
+           'add_cyclic_point', 'clone_ncvmain',
+           'format_coord_contour', 'format_coord_map', 'format_coord_scatter',
+           'get_slice',
            'list_intersection', 'set_axis_label', 'set_miss',
            'spinbox_values', 'vardim2var', 'zip_dim_name_length']
 
@@ -67,12 +79,54 @@ median - 50-percentile
 var - variance
 """
 
-
-SEPCHAR = chr(6)
+ios = platform.system()
+if ios == 'Darwin':
+    # SEPCHAR = chr(6)
+    SEPCHAR = chr(31)
+elif ios == 'Java':
+    SEPCHAR = chr(31)
+elif ios == 'Linux':
+    SEPCHAR = chr(31)
+elif ios == 'Windows':
+    SEPCHAR = chr(31)
+else:
+    SEPCHAR = chr(31)
 """
 Invisible character to split strings.
 
-ASCII character 6 = ACKNOWLEDGE (ACK)
+Name (Code) Decimal
+Null (NUL) 0
+Start of Heading (SOH) 1
+Start of Text (STX) 2
+End of Text (ETX) 3
+End of Transmit (EOT) 4
+Enquiry (ENQ) 5
+Acknowledge (ACK) 6
+Bell (BEL) 7
+Back Space (BS) 8
+Horizontal Tab (TAB) 9
+Line Feed (LF) 10
+Vertical Tab (VT) 11
+Form Feed (FF) 12
+Carriage Return (CR) 13
+Shift Out (SO) 14
+Shift In (SI) 15
+Data Line Escape (DLE) 16
+Device Control 1 (DC1) 17
+Device Control 2 (DC2) 18
+Device Control 3 (DC3) 19
+Device Control 4 (DC4) 20
+Negative Acknowledge (NAK) 21
+Synchronous Idle (SYN) 22
+End of Transmit Block (ETB) 23
+Cancel (CAN) 24
+End of Medium (EM) 25
+Substitute (SUB) 26
+Escape (ESC) 27
+File Separator (FS) 28
+Group Separator (GS) 29
+Record Separator (RS) 30
+Unit Separator (US) 31
 """
 
 
@@ -248,7 +302,8 @@ def add_cyclic_point(data, coord=None, rowcoord=None, axis=-1):
             # # delta_coord = np.diff(coord)
             # # if not np.allclose(delta_coord, delta_coord[0]):
             # #     raise ValueError('The coordinate must be equally spaced.')
-            # # new_coord = ma.concatenate((coord, coord[-1:] + delta_coord[0]))
+            # # new_coord = ma.concatenate((coord,
+            # #                             coord[-1:] + delta_coord[0]))
             # new code: just add 360 degree to first lon
             new_coord = np.ma.concatenate((coord, coord[0:1] + 360.))
         if (coord.ndim == 2):
@@ -302,10 +357,6 @@ def clone_ncvmain(widget):
     ----------
     widget : ncvue.ncvMain
         widget of ncvMain class.
-    fi : netCDF4._netCDF4.Dataset
-        netcdf dataset
-    miss : float
-        Additional value that will be set to np.nan in netcdf variables.
 
     Returns
     -------
@@ -341,6 +392,184 @@ def clone_ncvmain(widget):
     return clone
 
 
+def format_coord_contour(x, y, ax, xx, yy, zz):
+    """
+    Formatter function for contour plot including value of nearest array cell.
+
+    Parameters
+    ----------
+    x, y : float
+        Data coordinates of `ax`.
+    ax: matplotlib.axes._subplots.AxesSubplot
+        Matplotlib axes object for left-hand and right-hand y-axis, resp.
+    xx, yy, zz: ndarray
+        Numpy arrays with x-values, y-values, and z-values
+
+    Returns
+    -------
+    String with coordinateds.
+
+    Examples
+    --------
+    >>> ax = plt.subplot(111)
+    >>> ax.pcolormesh(xx, yy, zz)
+    >>> ax.format_coord = lambda x, y: format_coord_contour(
+    ...     x, y, ax, xx, yy, zz)
+    """
+    # find closest grid cell
+    # https://stackoverflow.com/questions/42577204/show-z-value-at-mouse-pointer-position-in-status-line-with-matplotlibs-pcolorme
+    if xx.ndim > 1:
+        xarr = xx[0, :]
+    else:
+        xarr = xx
+    if xx.dtype == np.dtype('<M8[ms]'):
+        xarr = mpld.date2num(xarr)
+    if yy.ndim > 1:
+        yarr = yy[:, 0]
+    else:
+        yarr = yy
+    if yy.dtype == np.dtype('<M8[ms]'):
+        yarr = mpld.date2num(yarr)
+    if ((x > xarr.min()) & (x <= xarr.max()) & 
+        (y > yarr.min()) & (y <= yarr.max())):
+        col = np.searchsorted(xarr, x) - 1
+        row = np.searchsorted(yarr, y) - 1
+        xout = xarr[col]
+        yout = yarr[row]
+        zout = zz[row, col]
+    else:
+        xout = x
+        yout = y
+        if zz.dtype == np.dtype('<M8[ms]'):
+            zout = np.datetime64('NaT')
+        else:
+            zout = np.nan
+
+    # Special treatment for datetime
+    # https://stackoverflow.com/questions/49267011/matplotlib-datetime-from-event-coordinates
+    if xx.dtype == np.dtype('<M8[ms]'):
+        xstr = mpld.num2date(xout).strftime('%Y-%m-%d %H:%M:%S')
+    else:
+        xstr  = '{:.4g}'.format(xout)
+    if yy.dtype == np.dtype('<M8[ms]'):
+        ystr = mpld.num2date(yout).strftime('%Y-%m-%d %H:%M:%S')
+    else:
+        ystr  = '{:.4g}'.format(yout)
+    if zz.dtype == np.dtype('<M8[ms]'):
+        zstr = mpld.num2date(zout).strftime('%Y-%m-%d %H:%M:%S')
+    else:
+        zstr = '{:.4g}'.format(zout)
+    out = 'x=' + xstr + ', y=' + ystr + ', z=' + zstr
+    return out
+
+
+def format_coord_map(x, y, ax, xx, yy, zz):
+    """
+    Formatter function for map including value of nearest array cell.
+
+    Parameters
+    ----------
+    x, y : float
+        Data coordinates of `ax`.
+    ax: matplotlib.axes._subplots.AxesSubplot
+        Matplotlib axes object for left-hand and right-hand y-axis, resp.
+    xx, yy, zz: ndarray
+        Numpy arrays with x-values, y-values, and z-values
+
+    Returns
+    -------
+    String with coordinateds.
+
+    Examples
+    --------
+    >>> ax = plt.subplot(111)
+    >>> ax.pcolormesh(xx, yy, zz)
+    >>> ax.format_coord = lambda x, y: format_coord_contour(
+    ...     x, y, ax, xx, yy, zz)
+    """
+    # find closest grid cell
+    xpp, ypp = ccrs.PlateCarree(central_longitude=0).transform_point(
+        x, y, ax.projection)
+    x360 = (xpp + 360.) % 360.
+    y360 = ypp
+    xx360 = (xx + 360.) % 360.
+    yy360 = yy
+    idx = np.abs((xx360 - x360)**2 + (yy360 - y360)**2).argmin()
+    xout = xx.flat[idx]
+    yout = yy.flat[idx]
+    zout = zz.flat[idx]
+
+    # from cartopy
+    lon, lat = ccrs.Geodetic().transform_point(x, y, ax.projection)
+
+    # xstr  = '{:.4g}'.format(xout)
+    # ystr  = '{:.4g}'.format(yout)
+    xstr  = '{:.4g}'.format(xout)
+    ystr  = '{:.4g}'.format(yout)
+    zstr  = '{:.4g}'.format(zout)
+    ns = 'N' if lat >= 0. else 'S'
+    ew = 'E' if lon >= 0. else 'W'
+    latstr = u'{:.4f} \u00b0{:s}'.format(abs(lat), ns)
+    lonstr = u'{:.4f} \u00b0{:s}'.format(abs(lon), ew)
+    out  = u'x=' + xstr + ', y=' + ystr + ' (' + lonstr + ', ' + latstr + ')'
+    out += ' z=' + zstr
+    return out
+
+
+def format_coord_scatter(x, y, ax, ax2, xdtype, ydtype, y2dtype):
+    """
+    Formatter function for scatter plot with left and right axis
+    having the same x-axis.
+
+    Parameters
+    ----------
+    x, y : float
+        Data coordinates of `ax2`.
+    ax, ax2: matplotlib.axes._subplots.AxesSubplot
+        Matplotlib axes object for left-hand and right-hand y-axis, resp.
+    xdtype, ydtype, y2dtype: numpy.dtype
+        Numpy dtype of data of x-values (xdtype), left-hand side y-values
+        (ydtype), and right-hand side y-values (y2dtype)
+
+    Returns
+    -------
+    String with left-hand side and right hand-side coordinates.
+
+    Examples
+    --------
+    >>> ax = plt.subplot(111)
+    >>> ax2 = ax.twinx()
+    >>> ax.plot(xx, yy)
+    >>> ax2.plot(xx, yy2)
+    >>> ax2.format_coord = lambda x, y: format_coord_scatter(
+    ...     x, y, ax, ax2, xx.dtype, yy.dtype, yy2.dtype)
+    """
+    # convert to display coords
+    # https://stackoverflow.com/questions/21583965/matplotlib-cursor-value-with-two-axes
+    display_coord = ax2.transData.transform((x, y))
+    # convert back to data coords with respect to ax
+    inv      = ax.transData.inverted()
+    ax_coord = inv.transform(display_coord)
+
+    # Special treatment for datetime
+    # https://stackoverflow.com/questions/49267011/matplotlib-datetime-from-event-coordinates
+    if xdtype == np.dtype('<M8[ms]'):
+        xstr = mpld.num2date(x).strftime('%Y-%m-%d %H:%M:%S')
+    else:
+        xstr  = '{:.3g}'.format(x)
+    if ydtype == np.dtype('<M8[ms]'):
+        ystr = mpld.num2date(ax_coord[1]).strftime('%Y-%m-%d %H:%M:%S')
+    else:
+        ystr  = '{:.3g}'.format(ax_coord[1])
+    if y2dtype == np.dtype('<M8[ms]'):
+        y2str = mpld.num2date(y).strftime('%Y-%m-%d %H:%M:%S')
+    else:
+        y2str = '{:.3g}'.format(y)
+    out  = 'Left: (' + xstr + ', ' + ystr + ')'
+    out += ' Right: (' + xstr + ', ' + y2str + ')'
+    return out
+
+
 def get_slice(dimspins, y):
     """
     Get slice of variable `y` inquiring the spinboxes `dimspins`.
@@ -475,19 +704,20 @@ def set_axis_label(ncvar):
 
 def set_miss(miss, x):
     """
-    Set `x` to NaN for all values in miss.
+    Set `x` to NaN or NaT for all values in miss.
 
     Parameters
     ----------
     miss : iterable
-        values which shall be set to np.nan in `x`
+        values which shall be set to np.nan or np.datetime64('NaT') in `x`
     x : ndarray
         numpy array
 
     Returns
     -------
     ndarray
-        `x` with all values set np.nan that are equal to any value in miss.
+        `x` with all values set np.nan or np.datetime64('NaT')
+        that are equal to any value in miss.
 
     Examples
     --------
@@ -495,8 +725,12 @@ def set_miss(miss, x):
     >>> miss = get_miss(self, x)
     >>> x = set_miss(miss, x)
     """
+    if x.dtype == np.dtype('<M8[ms]'):
+        default = np.datetime64('NaT')
+    else:
+        default = np.nan
     for mm in miss:
-        x = np.where(x == mm, np.nan, x)
+        x = np.where(x == mm, default, x)
     return x
 
 
