@@ -26,9 +26,11 @@ Released under the MIT License; see LICENSE file for details.
   Jan 2021, Matthias Cuntz
 * v3.2, Open netcdf files from within ncvue, Jan 2021, Matthias Cuntz
 * v3.3, Standalone apps for macOS and Windows, Feb 2021, Matthias Cuntz
+* v3.3.1, Better installation instructions, Feb 2021, Matthias Cuntz
+* v3.4, Print values, draw grid lines in contour, May 2021, Matthias Cuntz
 
 .. moduleauthor:: Matthias Cuntz
 """
 
 __author__  = "Matthias Cuntz"
-__version__ = "3.3"
+__version__ = "3.4"
